import { CreatePage } from '../pages/create'
import { HomePage } from '../pages/home'
import { LandingPage } from '../pages/landing/LandingPage'
import { Login } from '../pages/login'
import { ProfilePage } from '../pages/profile'
import { SettingsPage } from '../pages/settings/Settings'
import { CacheSettingsPage } from '../pages/settings/cache'
import { ProfileSettingsPage } from '../pages/settings/profile'
import { RelaysPage } from '../pages/settings/relays'
import { SignPage } from '../pages/sign'
import { VerifyPage } from '../pages/verify'
import { hexToNpub } from '../utils'

export const appPrivateRoutes = {
  homePage: '/',
  create: '/create',
  sign: '/sign',
  settings: '/settings',
  profileSettings: '/settings/profile/:npub',
  cacheSettings: '/settings/cache',
  relays: '/settings/relays'
}

export const appPublicRoutes = {
  profile: '/profile/:npub',
  landingPage: '/',
  login: '/login',
  verify: '/verify',
  source: 'https://git.sigit.io/sig/it'
}

export const getProfileRoute = (hexKey: string) =>
  appPublicRoutes.profile.replace(':npub', hexToNpub(hexKey))

export const getProfileSettingsRoute = (hexKey: string) =>
  appPrivateRoutes.profileSettings.replace(':npub', hexToNpub(hexKey))

export const publicRoutes = [
  {
    path: appPublicRoutes.landingPage,
    hiddenWhenLoggedIn: true,
    element: <LandingPage />
  },
  {
    path: appPublicRoutes.login,
    hiddenWhenLoggedIn: true,
    element: <Login />
  },
  {
    path: appPublicRoutes.profile,
    element: <ProfilePage />
  },
  {
    path: appPublicRoutes.verify,
    element: <VerifyPage />
  }
]

export const privateRoutes = [
  {
    path: appPrivateRoutes.homePage,
    element: <HomePage />
  },
  {
    path: appPrivateRoutes.create,
    element: <CreatePage />
  },
  {
    path: appPrivateRoutes.sign,
    element: <SignPage />
  },
  {
    path: appPrivateRoutes.settings,
    element: <SettingsPage />
  },
  {
    path: appPrivateRoutes.profileSettings,
    element: <ProfileSettingsPage />
  },
  {
    path: appPrivateRoutes.cacheSettings,
    element: <CacheSettingsPage />
  },
  {
    path: appPrivateRoutes.relays,
    element: <RelaysPage />
  }
]
